<template>
  <gree-view class="error-warn-page" bg-color="#fdfdfd">
    <gree-header :left-options="{ showBack: false }" :right-options="{ showMore: false }">
      <i class="iconfont iconfont-fanhui" slot="overwrite-left" @click="goBack" />
      {{ this.$language('errorPage.page_title') }}
    </gree-header>
    <gree-page>
      <gree-error-page type="malfunction" :background-image="cardBg" :text="errorContent" v-show="currentTheme === 0" />
    </gree-page>
    <gree-toolbar position="bottom" v-show="currentTheme === 0 && !isShowFooter">
      <gree-row>
        <gree-col v-for="(item, index) in options" :key="index" @click.native="setFunction(index)">
          <div class="icon">
            <i class="iconfont" :class="`iconfont-${item.icon}`" />
          </div>
          <h3>{{ item.Name }}</h3>
        </gree-col>
      </gree-row>
    </gree-toolbar>
  </gree-view>
</template>

<script>
import { ErrorPage, Header, TabBar, ToolBar, Row, Col } from 'gree-ui';
import { closePage, toWebPage, callNumber } from '@PluginInterface';
import { mapGetters, mapState } from 'vuex';
import { errorCode, errorCodeEn, codeParse } from '@/mixins/error';

export default {
  components: {
    [Col.name]: Col,
    [Row.name]: Row,
    [ErrorPage.name]: ErrorPage,
    [ToolBar.name]: ToolBar,
    [TabBar.name]: TabBar,
    [Header.name]: Header
  },
  data() {
    return {
      currentTheme: 0,
      themes: [
        {
          name: 0,
          label: this.$language('errorPage.tebBar_error')
        },
        {
          name: 1,
          label: this.$language('errorPage.tebBar_remind')
        }
      ],
      cardBg: require('@/assets/img/error_card.png'),
      options: [
        {
          icon: 'shouhoudianhua',
          Name: '售后电话'
        },
        {
          icon: 'yuyue',
          Name: '服务预约'
        },
        {
          icon: 'jinduchaxun',
          Name: '进度查询'
        }
      ]
    };
  },
  computed: {
    ...mapGetters(['errorMsgs', 'buttonDefine']),
    ...mapState('control', {
      ErrType: state => state.dataObject.ErrType,
      ErrType1: state => state.dataObject.ErrType1,
      ErrType2: state => state.dataObject.ErrType2
    }),
    // 将故障信息转化为显示内容格式
    errorContent() {
      const errorCodeObj = window.myvm.$i18n.locale === 'en' ? errorCodeEn : errorCode;
      let sortChar = [];
      if (this.ErrType > 0) {
        sortChar = [...sortChar, codeParse.ErrType[this.parseErrorJson(this.ErrType).length - 1]];
      }
      if (this.ErrType1 > 0) {
        sortChar = [...sortChar, codeParse.ErrType1[this.parseErrorJson(this.ErrType1).length - 1]];
      }
      if (this.ErrType2 > 0) {
        sortChar = [...sortChar, codeParse.ErrType2[this.parseErrorJson(this.ErrType2).length - 1]];
      }
      let result = [];
      sortChar.forEach(v => {
        result.push({
          code: v,
          title: errorCodeObj[v].title,
          headtitle: this.$language('errorPage.cardTitle') + '：',
          subtitle: this.$language('errorPage.bottom_title') + '：',
          text: this.$language('errorPage.bottom_text')
        });
      });
      return result;
    },
    isShowFooter() {
      const result = [];
      this.buttonDefine.forEach(item => {
        result.push(item.identifier);
      });
      return result.includes('Export');
    }
  },
  mounted() {},
  methods: {
    parseErrorJson(value) {
      return value
        .toString(2)
        .split('')
        .reverse()
        .map(Number);
    },
    setFunction(index) {
      switch (index) {
        case 0:
          callNumber(4008365315);
          break;
        case 1:
          toWebPage('http://pgxt.gree.com:7909/hjzx/bx/addbx.jsp?source=greejia', '服务预约');
          break;
        case 2:
          toWebPage('http://pgxt.gree.com:7909/hjzx/bx/chabx.jsp?source=greejia', '进度查询');
          break;
        default:
          console.log('Error，出错了！');
          break;
      }
    },
    goBack() {
      closePage();
    },
    onTabChange(item, index) {
      this.currentTheme = index;
    }
  }
};
</script>

<style lang="scss">
.error-warn-page {
  .page-content {
    padding-bottom: 0;
    .gree-tab-bar {
      background-color: #fdfdfd;
    }
  }
  .item-content {
    padding: 0 16px 0 52px !important;
    .item-inner {
      margin: 0 !important;
      padding-right: 0 !important;
      .item-title {
        white-space: inherit;
      }
      .item-after {
        word-wrap: break-word !important;
        white-space: inherit !important;
        width: 100%;
        height: auto;
      }
    }
  }
}
</style>

<style lang="scss" scoped>
$toolbarHeight: 270px;
$headerHeight: 127px;
.error-warn-page {
  .gree-header {
    background-color: #fdfdfd;
  }
  .page {
    padding-bottom: calc(#{$toolbarHeight} + env(safe-area-inset-top));
  }
  .item-content {
    .item-media {
      .logo {
        height: 180px !important;
      }
    }
  }
  .toolbar-bottom {
    background-color: rgb(244, 244, 244);
    height: $toolbarHeight;
    margin-bottom: env(safe-area-inset-top);
    .row {
      width: 100%;
      .col {
        display: flex;
        justify-content: center;
        flex-wrap: wrap;
        h3 {
          width: 100%;
          text-align: center;
        }
      }
    }
  }
  .icon {
    height: 132px;
    width: 132px;
    border-radius: 50%;
    background-color: #fff;
    display: flex;
    justify-content: center;
    align-items: center;
    box-shadow: 0 1px 4px rgba(0, 0, 0, 0.1);
    i {
      font-size: 68px;
    }
  }
}
</style>
